# iEvo Pipeline Context

> Cortex {{ cortex_version }} — compiled by `cortex compile`. Source: `templates/kernel/`.
> Do not edit — regenerated on every build.

{% include 'kernel/brainstem.md' %}

{% include 'kernel/instincts.md' %}

{% include 'kernel/limbic.md' %}

{% include 'kernel/neocortex.md' %}

{% include 'kernel/prefrontal.md' %}

{% include 'kernel/sessions.md' %}
